export = Commissioner;
declare class Commissioner {
    static StageEnum: {
        kError: number;
        kSecurePairing: number;
        kReadCommissioningInfo: number;
        kArmFailsafe: number;
        kConfigRegulatory: number;
        kSendPaiCertificateRequest: number;
        kSendDacCertificateRequest: number;
        kSendAttestationRequest: number;
        kAttestationVerification: number;
        kSendOpCertSigningRequest: number;
        kValidateCsr: number;
        kGenerateNocChain: number;
        kSendTrustedRootCert: number;
        kSendNoc: number;
        kWiFiNetworkSetup: number;
        kThreadNetworkSetup: number;
        kWiFiNetworkEnable: number;
        kThreadNetworkEnable: number;
        kFindOperational: number;
        kSendComplete: boolean;
        kCleanup: number;
        kScanNetworks: number;
        kNeedsNetworkCreds: number;
    };
    /**
     * Create a new commissioner instance.
     *
     * @param {Node} node
     */
    constructor(imManager: any, node: Node, params: any);
    _imManager: any;
    _node: Node;
    _onPairingError: any;
    _onOperationalCredentialsProvisioningError: any;
    _onOperationalCredentialsProvisioningComplete: any;
    /**
     * Returns next stage of the state machine give the current one.
     * @param {StageEnum} stage
     * @returns  {StageEnum} nextStage
     */
    getNextStage(stage: StageEnum): StageEnum;
    stageSecurePairing(): void;
    onPairingComplete(session: any): void;
    _session: any;
    _exchange: any;
    onPairingError(session: any): void;
    stageReadCommissioningInfo(): void;
    onCommissioningInfoReport(): void;
    stageArmFailSafe(): void;
    _state: number | undefined;
    onArmFailSafe(): void;
    stageConfigRegulatory(): void;
    onConfigRegulatory(): void;
    stageSendPaiCertificateRequest(): void;
    onPaiCertificateResponse(): void;
    stageSendDacCertificateRequest(): void;
    onDacCertificateResponse(): void;
    stageSendAttestationRequest(): void;
    onAttestationResponse(): void;
    stageAttestationVerification(): void;
    stageSendOpCertSigningRequest(): void;
    onOpCertSigningResponse(): void;
    stageValidateCsr(): void;
    stageGenerateNocChain(): void;
    stageSendTrustedRootCert(): void;
    stageSendNoc(): void;
    stageFindOperational(): void;
    stageSendComplete(): void;
    /**
     * Dispatch work for the current stage of the state machine and await the
     * transition event that will trigger the next stage.
     *
     * @param {StageEnum} stage
     */
    performStage(stage: StageEnum): any;
    /**
     * Commission the given device onto the given fabric.
     * //@param {*} device
     * @param {*} fabric
     */
    pair(device: any, pincode: any, nodeid: any, fabric: any): void;
    _device: any;
    _pincode: any;
    _stage: number | undefined;
}
