export = ChipCert;
/**
 * Copyright 2022 Project CHIP Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
declare class ChipCert {
    static kMaxCHIPCertLength: number;
    static kMaxDERCertLength: number;
    static TlvTagStructure: {
        SerialNumber: number;
        SignatureAlgorithm: number;
        Issuer: number;
        NotBefore: number;
        NotAfter: number;
        Subject: number;
        PublicKeyAlgorithm: number;
        EllipticCurveId: number;
        PublicKey: number;
        Extensions: number;
        Signature: number;
    };
    static TlvTagExtensions: {
        BasicConstraints: number;
        KeyUsage: number;
        ExtendedKeyUsage: number;
        SubjectKeyId: number;
        AuthorityKeyId: number;
        FutureExtension: number;
    };
    static TlvTagDn: {
        CommonName: number;
        Surname: number;
        SerialNumber: number;
        CountryName: number;
        LocalityName: number;
        StateOrProvinceName: number;
        OrgName: number;
        OrgUnitName: number;
        Title: number;
        Name: number;
        GivenName: number;
        Initials: number;
        GenQualifier: number;
        DnQualifier: number;
        Pseudonym: number;
        DomainComponent: number;
        MatterNodeId: number;
        MatterFirmwareSigningId: number;
        MatterIcacId: number;
        MatterRcacId: number;
        MatterFabricId: number;
        MatterNocCat: number;
        CommonNamePs: number;
        SurnamePs: number;
        SerialNumPs: number;
        CountryNamePs: number;
        LocalityNamePs: number;
        StateOrProvinceNamePs: number;
        OrgNamePs: number;
        OrgUnitNamePs: number;
        TitlePs: number;
        NamePs: number;
        GivenNamePs: number;
        InitialsPs: number;
        GenQualifierPs: number;
        DnQualifierPs: number;
        PseudonymOs: number;
    };
    static TlvTagBasicConstraints: {
        kTag_BasicConstraints_IsCA: number;
        kTag_BasicConstraints_PathLenConstraint: number;
    };
    /** Identifies the purpose or application of certificate
     *
     * A certificate type is a label that describes a certificate's purpose or application.
     * Certificate types are not carried as attributes of the corresponding certificates, but
     * rather are derived from the certificate's structure and/or the context in which it is used.
     * The certificate type enumeration includes a set of pre-defined values describing commonly
     * used certificate applications.
     *
     * Certificate types are primarily used in the implementation of access control policies,
     * where access to application features is influenced by the type of certificate presented
     * by a requester.
     *
     * @note Cert type is an API data type only; it should never be sent over-the-wire.
     */
    static CertType: {
        kCertType_NotSpecified: number;
        kCertType_Root: number;
        kCertType_ICA: number;
        kCertType_Node: number;
        kCertType_FirmwareSigning: number;
    };
    /** X.509 Certificate Key Purpose Flags
     *
     *    The flags order must match the enumeration order of corresponding kOID_KeyPurpose values.
     */
    static KeyPurposeFlags: {
        kServerAuth: number;
        kClientAuth: number;
        kCodeSigning: number;
        kEmailProtection: number;
        kTimeStamping: number;
        kOCSPSigning: number;
    };
    /** X.509 Certificate Key Usage Flags
     */
    static KeyUsageFlags: {
        kDigitalSignature: number;
        kNonRepudiation: number;
        kKeyEncipherment: number;
        kDataEncipherment: number;
        kKeyAgreement: number;
        kKeyCertSign: number;
        kCRLSign: number;
        kEncipherOnly: number;
        kDecipherOnly: number;
    };
    /** CHIP Certificate Flags
     *
     * Contains information about a certificate that has been loaded into a ChipCertificateData object.
     */
    static CertFlags: {
        kExtPresent_BasicConstraints: number;
        kExtPresent_KeyUsage: number;
        kExtPresent_ExtendedKeyUsage: number;
        kExtPresent_SubjectKeyId: number;
        kExtPresent_AuthKeyId: number;
        kExtPresent_FutureIsCritical: number;
        kPathLenConstraintPresent: number;
        kIsCA: number;
        kIsTrustAnchor: number;
        kTBSHashPresent: number;
    };
    /** CHIP Certificate Decode Flags
     *
     * Contains information specifying how a certificate should be decoded.
     */
    static CertDecodeFlags: {
        kGenerateTBSHash: number;
        kIsTrustAnchor: number;
    };
    static kNullCertTime: number;
}
