export = Message;
/**
 * Message is the core utility class for encode / decode of the raw Matter message format.
 *
 * ExchangeManager will add the following fields during processing:
 *      .Exchange -- the Exchange object associated with the recieved message.
 */
declare class Message {
    static SESSION_ID_UNSECURED: number;
    static MESSAGE_HEADER_MIN_SIZE: number;
    static MESSAGE_HEADER_CLEARTEXT_SIZE: number;
    static EXCHANGE_HEADER_MIN_SIZE: number;
    static MESSAGE_NODE_ID_SIZE: number;
    static MESSAGE_GROUP_ID_SIZE: number;
    static CRYPTO_AEAD_MIC_LENGTH_BYTES: number;
    static ACK_COUNTER_SIZE: number;
    static DestinationType: {
        Omit: number;
        NodeId: number;
        GroupId: number;
    };
    static SourceType: {
        Omit: number;
        NodeId: number;
    };
    constructor(buf?: undefined, enc?: null, peerInfo?: null);
    _buffer: any;
    _encrypted: any;
    _peerInfo: any;
    _hasSource: boolean;
    _hasDestination: boolean;
    set Decrypted(arg: any);
    get Decrypted(): any;
    set Encrypted(arg: any);
    get Encrypted(): any;
    set PeerInfo(arg: any);
    get PeerInfo(): any;
    set MessageFlags(arg: any);
    get MessageFlags(): any;
    set SessionId(arg: any);
    get SessionId(): any;
    set SecurityFlags(arg: any);
    get SecurityFlags(): any;
    set MessageCounter(arg: any);
    get MessageCounter(): any;
    get Version(): number;
    set Sflag(arg: boolean);
    get Sflag(): boolean;
    set Dsiz(arg: number);
    get Dsiz(): number;
    get Mic(): any;
    set SourceNodeId(arg: any);
    get SourceNodeId(): any;
    set DestinationNodeId(arg: any);
    get DestinationNodeId(): any;
    get Pflag(): boolean;
    get Cflag(): boolean;
    get Mxflag(): boolean;
    get SessionType(): number;
    get PayloadOffset(): number;
    get Payload(): any;
    set ExchangeFlags(arg: any);
    get ExchangeFlags(): any;
    set ProtocolOpcode(arg: any);
    get ProtocolOpcode(): any;
    set ExchangeId(arg: any);
    get ExchangeId(): any;
    set ProtocolId(arg: number);
    get ProtocolId(): number;
    set Iflag(arg: boolean);
    get Iflag(): boolean;
    set Aflag(arg: boolean);
    get Aflag(): boolean;
    set Rflag(arg: boolean);
    get Rflag(): boolean;
    get Sxflag(): boolean;
    get Vflag(): boolean;
    set AckCounter(arg: any);
    isUnencrypted(): boolean;
    isEncrypted(): boolean;
    set AppPayload(arg: any);
    get AppPayload(): any;
    /**
     * Calculate Encryption Nonce for the given plaintext message.
     *
     * @see 4.7.1.1. Nonce
     * N = Security Flags || Message Counter || Source Node ID
     */
    get Nonce(): Buffer;
    /**
     * Calculate the Privacy Nonce for the given encrypted message.
     *
     * @see 4.8.2. Privacy Processing of Outgoing Messages
     * N = Session ID || MIC[(CRYPTO_AEAD_NONCE_LENGTH_BYTES-3)..0]
     */
    get PrivacyNonce(): Buffer;
    encrypt(key: any, apply?: boolean): Buffer | undefined;
    decrypt(key: any, apply?: boolean): Buffer | undefined;
    /**
     * Obfuscate the plaintext header portions of the encrypted message.
     *
     * @param {Buffer} privacyKey The privacy key to use for obfuscation.
     * @param {boolean} apply If true, the deobfuscated header will be applied to the message.
     * @returns {Buffer} The deobfuscated header.
     */
    privacyEncrypt(privacyKey: Buffer, apply?: boolean): Buffer;
    /**
     * Deobfuscate the private header portions of the encrypted message.
     *
     * @param {Buffer} privacyKey The privacy key to use for deobfuscation.
     * @param {boolean} apply If true, the deobfuscated header will be applied to the message.
     * @returns {Buffer} The deobfuscated header.
     */
    privacyDecrypt(privacyKey: Buffer, apply?: boolean): Buffer;
}
