export = SessionManager;
/**
 * SessionManager consumes 'message' events from the transport layer (UdpServer),
 * manages the table of active Session contexts, matches messages with those sessions,
 * and then dispatches the messages to subsequent event subscribers such as ExchangeManager.
 *
 * dgram.emit('message')
 *   \--> UdpServer.emit('message')
 *          \--> SessionManager.emit('message)
 *                 |--> ExchangeManager.emit('unsolicitedMessage')
 *                 |--> Exchange.emit('exchangeMessage')
 *
 * SessionManager emits the following Events:
 *
 * Event: 'message'
 *   The SessionManager 'message' event is emitted when a new datagram is available on a session.
 *   The event handler function is passed three arguments: msg, peerInfo, and session.
 *
 *      msg <Message object> The message.
 *      peerInfo <Object> Remote address information.
 *          address <string> The sender address.
 *          family <string> The address family ('IPv4' or 'IPv6').
 *          port <number> The sender port.
 *          size <number> The message size.
 *      session <Session object> The session associated with the message.
 *
 *    If the source address of the incoming packet is an IPv6 link-local address,
 *    the interface name is added to the address. For example, a packet received
 *    on the en0 interface might have the address field set to 'fe80::2618:1234:ab11:3b9c%en0',
 *    where '%en0' is the interface name as a zone ID suffix.
 */
declare class SessionManager extends EventEmitter {
    constructor(udpServer: any);
    _sessionsSecured: any[];
    _sessionsUnsecured: any[];
    _nextSessionId: number;
    _udpServer: any;
    get SecureSessions(): any[];
    get UnsecuredSessions(): any[];
    getSecureSession(sessionId: any): any;
    getUnsecureSession(peerInfo: any, peerNodeId: any): any;
    newSession(localSessionId: any, peerSessionId: any, isSecure?: boolean): Session;
    newUnsecuredSession(): Session;
    addSocket(udpSocket: any): void;
    onUnsecuredMessage(msg: any): any;
    onSecureMessage(buf: any, peerInfo: any): Message | undefined;
    onMessage(buf: any, peerInfo: any): void;
}
import EventEmitter = require("events");
import Session = require("./Session");
import Message = require("./Message");
