export = StatusReport;
declare class StatusReport {
    static PROTOCOL_ID: number;
    static OPCODE: number;
    static GeneralCode: {
        SUCCESS: number;
        FAILURE: number;
        BAD_PRECONDITION: number;
        OUT_OF_RANGE: number;
        BAD_REQUEST: number;
        UNSUPPORTED: number;
        UNEXPECTED: number;
        RESOURCE_EXHAUSTED: number;
        BUSY: number;
        TIMEOUT: number;
        CONTINUE: number;
        ABORTED: number;
        INVALID_ARGUMENT: number;
        NOT_FOUND: number;
        ALREADY_EXISTS: number;
        PERMISSION_DENIED: number;
        DATA_LOSS: number;
    };
    /**
     * Send a Status Report with the given payload format:
     *
     * +----------+--------------+------------------------------------------------------
     * | SIZE     | FIELD        | DESCRIPTION
     * | [bytes]  |              |
     * |----------|--------------|------------------------------------------------------
     * |    2     | GeneralCode  |
     * |    4     | ProtocolId   | Protocol-Specific Status
     * |    2     | ProtocolCode | Protocol-Specific Status
     * | Variable | ProtocolData | Optional Protocol-Specific TLV, MAY be empty
     * +----------+--------------+------------------------------------------------------
     *
     * @param {*} exchange Exchange to send status report to
     * @param {*} payload Buffer with preformatted status report message (per spec above)
     */
    static send(exchange: any, payload: any): void;
    static sendStatus(exchange: any, generalCode: any, protocolId: any, protocolCode: any, protocolData?: undefined): void;
    static sendSuccess(exchange: any, protocolId: any, protocolCode: any, protocolData?: undefined): void;
}
