/**
 * Copyright 2022 Project CHIP Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { TlvType } from "./TlvType";
/**
 * Utility class for parsing TLV objects
 */
export declare class TlvParser {
    /**
     * Safely stringify a deterministic TLV JSON object, accounting for bigint.
     *
     * @param tlvJson
     * @returns {string} JSON representation of the TLV object
     */
    static JsonStringify(tlvJson: Array<TlvType.DeterministicJson>): string;
    static findTag(tlvJson: Array<TlvType.DeterministicJson>, tag: number): any;
    static setNameForTag(tlvJson: Array<TlvType.DeterministicJson>, tag: number, tagName: string): void;
    /**
     * Find and return the entry with the given tag name.
     */
    static get(tlvJson: Array<TlvType.DeterministicJson>, tagName: string): any;
    static mapFields(tlvJson: Array<TlvType.DeterministicJson>, tagNameMap: Map<number, string>): void;
}
