"use strict";
/**
 * Copyright 2022 Project CHIP Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TlvParser = void 0;
/**
 * Utility class for parsing TLV objects
 */
class TlvParser {
    /**
     * Safely stringify a deterministic TLV JSON object, accounting for bigint.
     *
     * @param tlvJson
     * @returns {string} JSON representation of the TLV object
     */
    static JsonStringify(tlvJson) {
        const replacer = (key, value) => {
            typeof value === 'bigint'
                ? value.toString() // convert any bigint to string
                : value; // return everything else unchanged
        };
        return JSON.stringify(tlvJson, replacer);
    }
    static findTag(tlvJson, tag) {
        const entry = tlvJson.find(element => element.tag === tag);
        return (entry != undefined) ? entry.value : undefined;
    }
    static setNameForTag(tlvJson, tag, tagName) {
        const entry = tlvJson.find(element => element.tag === tag);
        if (entry != undefined) {
            entry.tagName = tagName;
        }
    }
    /**
     * Find and return the entry with the given tag name.
     */
    static get(tlvJson, tagName) {
        const entry = tlvJson.find(element => element.tagName === tagName);
        return (entry != undefined) ? entry.value : undefined;
    }
    static mapFields(tlvJson, tagNameMap) {
        tlvJson.forEach(element => {
            if (element.tag && tagNameMap.has(element.tag)) {
                element.tagName = tagNameMap.get(element.tag);
            }
        });
    }
}
exports.TlvParser = TlvParser;
//# sourceMappingURL=TlvParser.js.map