/// <reference types="node" />
export = tracer;
declare var tracer: Tracer;
/**
 * Generates a trace file that can be loaded into chrome://tracing or ui.perfetto.dev.
 * In perfetto, events can be seen with the following SQL query followed by CTRL+Enter:
 *
 *      SELECT * FROM slices WHERE category == matternode
 */
declare class Tracer {
    static TRACE_FILE: string;
    static TRACE_CATEGORY: string;
    static TRACE_DURATION: number;
    static Type: {
        Begin: string;
        End: string;
        Complete: string;
        Meta: string;
        Instant: string;
        Counter: string;
        Sample: string;
        MemGlobal: string;
        MemProcess: string;
        Obj: string;
        ObjNew: string;
        ObjDestroy: string;
        AsyncBegin: string;
        AsyncInstant: string;
        AsyncEnd: string;
        FlowStart: string;
        FlowStep: string;
        FlowEnd: string;
        ClockSync: string;
    };
    constructor(filename?: string);
    _traceLevel: number;
    _writer: fs.WriteStream;
    _pid: number;
    set level(arg: number);
    get level(): number;
    writeHeader(): void;
    writeFooter(): void;
    emit(name: any, ph: string | undefined, args: any): void;
    begin(name?: string): void;
    end(name?: string): void;
    event(name?: string): void;
    instant(name?: string): void;
    asyncBegin(name?: string): void;
    asyncStep(name?: string): void;
    asyncEnd(name?: string): void;
    flowStart(name?: string): void;
    flowStep(name?: string): void;
    flowEnd(name?: string): void;
    meta(name?: string, args?: {}): void;
    obj(name?: string, args?: {}): void;
    objNew(name?: string, args?: {}): void;
    objDestroy(name?: string, args?: {}): void;
    memGlobal(name?: string, args?: {}): void;
    memTask(name?: string, args?: {}): void;
}
import fs = require("fs");
